# CLAUDE.md

This file provides guidance to Claude Code (claude.ai/code) when working with code in this repository.

Read the [Agent instructions](AGENTS.md) for guidance on how to use AI Agents with this repository.
